@@ -41,6 +41,10 @@ clients_mapping = {
             "index": "not_analyzed",
             "type": "string"
         },
+        "project_id": {
+            "index": "not_analyzed",
+            "type": "string"
+        },
         "uuid": {
             "index": "not_analyzed",
             "type": "string"
@@ -203,9 +207,6 @@ backups_mapping = {
                 }
             }
         },
-        "backup_uuid": {
-            "type": "string"
-        },
         "user_id": {
             "index": "not_analyzed",
             "type": "string"
@@ -220,6 +221,10 @@ backups_mapping = {
         "job_id": {
             "index": "not_analyzed",
             "type": "string"
+        },
+        "project_id": {
+            "index": "not_analyzed",
+            "type": "string"
         }
     }
 }
@@ -242,6 +247,10 @@ jobs_mapping = {
                     "index": "not_analyzed",
                     "type": "string"
                 },
+                "project_id": {
+                    "index": "not_analyzed",
+                    "type": "string"
+                },
                 "freezer_action": {
                     "properties": {
                         "action": {
@@ -403,6 +412,10 @@ jobs_mapping = {
         "user_id": {
             "index": "not_analyzed",
             "type": "string"
+        },
+        "project_id": {
+            "index": "not_analyzed",
+            "type": "string"
         }
     }
 }
